==> haskell-unicode-show-0.1.0.2-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-unicode-show.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unicode-show
version: 0.1.0.2
id: unicode-show-0.1.0.2-96R9Y5WWuoIFTOKQeD1HeM
key: unicode-show-0.1.0.2-96R9Y5WWuoIFTOKQeD1HeM
license: BSD-3-Clause
copyright: 2016 Takayuki Muranushi
maintainer: muranushi@gmail.com
author: Takayuki Muranushi
homepage: http://github.com/nushio3/unicode-show#readme
synopsis: print and show in unicode
description:
    This package provides variants of '\''show'\'' and '\''print'\'' functions that does not escape non-ascii characters.
    .
    See <http://github.com/nushio3/unicode-show#readme README> for usage.
    .
    Run ghci with  @-interactive-print@ flag to print unicode characters. See <https://downloads.haskell.org/~ghc/latest/docs/html/users_guide/interactive-evaluation.html#ghci-interactive-print Using a custom interactive printing function> section in the GHC manual.
category: Text
abi: f9afaf8a5129f5364bc3a991a2f743be
exposed: True
exposed-modules:
    Text.Show.Unicode
import-dirs: /usr/lib/ghc-8.4.3/site-local/unicode-show-0.1.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/unicode-show-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/unicode-show-0.1.0.2
hs-libraries: HSunicode-show-0.1.0.2-96R9Y5WWuoIFTOKQeD1HeM
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-unicode-show/html/unicode-show.haddock
haddock-html: /usr/share/doc/haskell-unicode-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unicode-show-0.1.0.3-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-unicode-show.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unicode-show
version: 0.1.0.3
id: unicode-show-0.1.0.3-CotN7zxqeHFDHCw3hquS7M
key: unicode-show-0.1.0.3-CotN7zxqeHFDHCw3hquS7M
license: BSD-3-Clause
copyright: 2016 Takayuki Muranushi
maintainer: whosekiteneverfly@gmail.com
author: Takayuki Muranushi
homepage: http://github.com/haskell-jp/unicode-show#readme
synopsis: print and show in unicode
description:
    This package provides variants of '\''show'\'' and '\''print'\'' functions that does not escape non-ascii characters.
    .
    See <http://github.com/haskell-jp/unicode-show#readme README> for usage.
    .
    Run ghci with  @-interactive-print@ flag to print unicode characters. See <https://downloads.haskell.org/~ghc/latest/docs/html/users_guide/interactive-evaluation.html#ghci-interactive-print Using a custom interactive printing function> section in the GHC manual.
category: Text
abi: 88ebef741ed205523646a31fae16d1c4
exposed: True
exposed-modules:
    Text.Show.Unicode
import-dirs: /usr/lib/ghc-8.4.3/site-local/unicode-show-0.1.0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/unicode-show-0.1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/unicode-show-0.1.0.3
hs-libraries: HSunicode-show-0.1.0.3-CotN7zxqeHFDHCw3hquS7M
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-unicode-show/html/unicode-show.haddock
haddock-html: /usr/share/doc/haskell-unicode-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
